/*
 * This file is part of Invenio.
 * Copyright (C) 2015-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

.text-white {
  color: $text-white;

  a,
  a:focus,
  a:hover {
    color: $text-white;
  }
}

a.text-white,
a.text-white:focus,
a.text-white:hover {
  color: $text-white;
}
