/*
 * This file is part of Invenio.
 * Copyright (C) 2016-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

require([
  "jquery",
  "select2",
  ], function() {
  // loading select2 module for the not require.js ready scripts
  // everywhere.
})
