{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends config.THEME_SETTINGS_TEMPLATE %}

{% set panel_icon="fa fa-cog" %}
{% set panel_title="Panel header" %}

{% block settings_form %}
<p>Select an item from the menu.</p>
{% endblock settings_form %}
