/*
 * This file is part of Invenio.
 * Copyright (C) 2015-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

 require([
    "jquery",
    "bootstrap"
    ], function() {
    // loading all the jQuery modules for the not require.js ready scripts
    // everywhere.
})
