{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends config.THEME_SETTINGS_TEMPLATE %}

{% set panel_icon="fa fa-wrench" %}
{% set panel_title="Form example with message flashing" %}

{% block settings_form %}
<form action="/settings/1">
<div class="form-group">
    <label class="control-label" for="password">{{_('Example Field 1')}}</label>
    <input class="form-control" type="text"></input>
</div>
<div class="form-group">
    <label class="control-label" for="password">{{_('Example Field 2')}}</label>
    <input class="form-control" type="text"></input>
</div>
<div class="form-actions">
    <button type="submit" class="btn btn-primary">{{_('Submit')}}</button>
</div>
</form>
{% endblock settings_form %}
